/* main-dos.c */

#ifdef __cplusplus
extern "C" {
#endif

int	main_dos( void );
void	chk_arg( int argc, char **argv );
bool_t	chk_opt_flg( const char *optarg );
void	overwrite_arg();
void	usage( FILE *fp );
void	child_ps_dos( void );
void	init_term_dos( void );
bool_t	chk_term_dos( void );
void	ena_term_dos( void );
void	dis_term_dos( void );
void	set_key_wait_dos( void );
void	clr_key_wait_dos( void );
void	set_key_wait_vtime( long wait_vtime );

#ifdef __cplusplus
}
#endif
